Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(321)

Unified Diff: pkg/analysis_server/lib/src/services/index/store/split_store.dart

Issue 1100673005: Rename IndexStore to avoid confusion with the new public API (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/src/services/index/store/split_store.dart
diff --git a/pkg/analysis_server/lib/src/services/index/store/split_store.dart b/pkg/analysis_server/lib/src/services/index/store/split_store.dart
index 6610d8afd1961e51636fc6ebee8fb25614b77ff3..b3c9ef14b87a3b8d67bd866e2f397884fac21803 100644
--- a/pkg/analysis_server/lib/src/services/index/store/split_store.dart
+++ b/pkg/analysis_server/lib/src/services/index/store/split_store.dart
@@ -19,25 +19,6 @@ import 'package:analyzer/src/generated/java_engine.dart';
import 'package:analyzer/src/generated/source.dart';
import 'package:analyzer/src/generated/utilities_general.dart';
-class _TopElementData {
- final String name;
- final int elementId1;
- final int elementId2;
- final int elementId3;
-
- factory _TopElementData(ElementCodec elementCodec, Element element) {
- return new _TopElementData._(element.name, elementCodec.encode1(element),
- elementCodec.encode2(element), elementCodec.encode3(element));
- }
-
- _TopElementData._(
- this.name, this.elementId1, this.elementId2, this.elementId3);
-
- Element getElement(AnalysisContext context, ElementCodec elementCodec) {
- return elementCodec.decode(context, elementId1, elementId2, elementId3);
- }
-}
-
/**
* A manager for files content.
*/
@@ -517,11 +498,6 @@ class RelationKeyData {
}
@override
- String toString() {
- return 'Key($elementId2, $elementId2, $elementId3, $relationshipId)';
- }
-
- @override
bool operator ==(Object obj) {
if (obj is! RelationKeyData) {
return false;
@@ -532,12 +508,18 @@ class RelationKeyData {
other.elementId3 == elementId3 &&
other.relationshipId == relationshipId;
}
+
+ @override
+ String toString() {
+ return 'Key($elementId2, $elementId2, $elementId3, $relationshipId)';
+ }
}
/**
* An [IndexStore] which keeps index information in separate nodes for each unit.
*/
-class SplitIndexStore implements IndexStore {
+class SplitIndexStore implements InternalIndexStore {
/**
* The [ContextCodec] to encode/decode [AnalysisContext]s.
*/
@@ -1033,3 +1015,22 @@ class _DataOutputStream {
_buf[_pos++] = value;
}
}
+
+class _TopElementData {
+ final String name;
+ final int elementId1;
+ final int elementId2;
+ final int elementId3;
+
+ factory _TopElementData(ElementCodec elementCodec, Element element) {
+ return new _TopElementData._(element.name, elementCodec.encode1(element),
+ elementCodec.encode2(element), elementCodec.encode3(element));
+ }
+
+ _TopElementData._(
+ this.name, this.elementId1, this.elementId2, this.elementId3);
+
+ Element getElement(AnalysisContext context, ElementCodec elementCodec) {
+ return elementCodec.decode(context, elementId1, elementId2, elementId3);
+ }
+}

Powered by Google App Engine
This is Rietveld 408576698
@@ -532,12 +508,18 @@ class RelationKeyData {
}
/**
- * An [IndexStore] which keeps index information in separate nodes for each unit.
+ * An [InternalIndexStore] which keeps index information in separate nodes for
+ * each unit.
*/